@@ -144,7 +144,8 @@ void mm_display_info(MM *mm)
     int nAlloc;
     int i;
 
-    mm_core_lock((void *)mm, MM_LOCK_RD);
+    if (!mm_core_lock((void *)mm, MM_LOCK_RD))
+        return;
     mc = &(mm->mp_freechunks);
     nFree   = 0;
     while (mc->mc_u.mc_next != NULL) {
@@ -192,7 +193,8 @@ static void mm_insert_chunk(MM *mm, mem_chunk *mcInsert)
     mem_chunk *mcPrev;
     mem_chunk *mcNext;
     
-    mm_core_lock((void *)mm, MM_LOCK_RW);
+    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
+        return;
     mc = &(mm->mp_freechunks);
     while (mc->mc_u.mc_next != NULL && (char *)(mc->mc_u.mc_next) < (char *)mcInsert)
         mc = mc->mc_u.mc_next;
@@ -242,7 +244,8 @@ static mem_chunk *mm_retrieve_chunk(MM *mm, size_t size)
 
     if (mm->mp_freechunks.mc_usize == 0)
         return NULL;
-    mm_core_lock((void *)mm, MM_LOCK_RW);
+    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
+        return NULL;
     /* find best-fitting chunk */
     pmcMin = NULL;
     sMin = mm->mp_size; /* maximum possible */
@@ -298,7 +301,8 @@ void *mm_malloc(MM *mm, size_t usize)
         mc->mc_usize = usize;
         return &(mc->mc_u.mc_base.mw_cp);
     }
-    mm_core_lock((void *)mm, MM_LOCK_RW);
+    if (!mm_core_lock((void *)mm, MM_LOCK_RW))
+        return NULL;
     if ((mm->mp_size - mm->mp_offset) < size) {
         mm_core_unlock((void *)mm);
         ERR(MM_ERR_ALLOC, "Out of memory");
@@ -419,7 +423,8 @@ size_t mm_available(MM *mm)
     mem_chunk *mc;
     int nFree;
 
-    mm_core_lock((void *)mm, MM_LOCK_RD);
+    if (!mm_core_lock((void *)mm, MM_LOCK_RD))
+        return 0;
     nFree = mm->mp_size-mm->mp_offset;
     mc = &(mm->mp_freechunks);
     while (mc->mc_u.mc_next != NULL) {
